@@ -561,8 +561,42 @@ class TestCTE(TestCase):
             .order_by("amount")
         )
 
-        # the test db (sqlite3) doesn't support EXPLAIN, so let's just check
-        # to make sure EXPLAIN is at the top
-        orders.query.explain_query = True
+        self.assertIsInstance(orders.explain(), str)
 
-        self.assertTrue(str(orders.query).startswith("EXPLAIN "))
+    def test_empty_result_set_cte(self):
+        """
+        Verifies that the CTEQueryCompiler can handle empty result sets in the
+        related CTEs
+        """
+        totals = With(
+            Order.objects
+            .filter(id__in=[])
+            .values("region_id")
+            .annotate(total=Sum("amount")),
+            name="totals",
+        )
+        orders = (
+            totals.join(Order, region=totals.col.region_id)
+            .with_cte(totals)
+            .annotate(region_total=totals.col.total)
+            .order_by("amount")
+        )
+
+        self.assertEqual(len(orders), 0)
+
+    def test_left_outer_join_on_empty_result_set_cte(self):
+        totals = With(
+            Order.objects
+            .filter(id__in=[])
+            .values("region_id")
+            .annotate(total=Sum("amount")),
+            name="totals",
+        )
+        orders = (
+            totals.join(Order, region=totals.col.region_id, _join_type=LOUTER)
+            .with_cte(totals)
+            .annotate(region_total=totals.col.total)
+            .order_by("amount")
+        )
+
+        self.assertEqual(len(orders), 22)
